@@ -47,7 +47,7 @@ class List(Storm):
 
     name = Unicode(primary=True)
     display_name = Unicode()
-    description = Unicode()
+    subject_prefix = Unicode()
 
     def __init__(self, name):
         self.name = unicode(name)
@@ -201,7 +201,7 @@ class Thread(Storm):
         """Set of email senders in this thread"""
         p = []
         for sender in self.emails.find().config(distinct=True
-                        ).order_by().values(Email.sender_name):
+                        ).order_by().values(Email.sender_name, Email.sender_email):
             p.append(sender)
         return p
 
