@@ -90,7 +90,7 @@ class StormStore(object):
             l = List(list_name)
             self.db.add(l)
         l.display_name = mlist.display_name
-        l.description = mlist.description
+        l.subject_prefix = mlist.subject_prefix
         if not message.has_key("Message-Id"):
             raise ValueError("No 'Message-Id' header in email", message)
         msg_id = unicode(unquote(message['Message-Id']))
@@ -257,7 +257,7 @@ class StormStore(object):
         """
         emails = self.db.find(Email, And(
                     Email.list_name == unicode(list_name),
-                    Email.content.ilike(u'%{0}%'.format(keyword))
+                    Email.content.like(u'%{0}%'.format(keyword), case_sensitive = False)
                 )).order_by(Desc(Email.date))
         return emails
 
@@ -273,8 +273,8 @@ class StormStore(object):
         emails = self.db.find(Email, And(
                     Email.list_name == unicode(list_name),
                     Or(
-                        Email.content.ilike(u'%{0}%'.format(keyword)),
-                        Email.subject.ilike(u'%{0}%'.format(keyword)),
+                        Email.content.like(u'%{0}%'.format(keyword), case_sensitive = False),
+                        Email.subject.like(u'%{0}%'.format(keyword), case_sensitive = False),
                 ))).order_by(Desc(Email.date))
         return emails
 
@@ -289,8 +289,8 @@ class StormStore(object):
         emails = self.db.find(Email, And(
                     Email.list_name == unicode(list_name),
                     Or(
-                        Email.sender_name.ilike(u'%{0}%'.format(keyword)),
-                        Email.sender_email.ilike(u'%{0}%'.format(keyword)),
+                        Email.sender_name.like(u'%{0}%'.format(keyword), case_sensitive = False),
+                        Email.sender_email.like(u'%{0}%'.format(keyword), case_sensitive = False),
                 ))).order_by(Desc(Email.date))
         return emails
 
@@ -304,7 +304,7 @@ class StormStore(object):
         """
         emails = self.db.find(Email, And(
                     Email.list_name == unicode(list_name),
-                    Email.subject.ilike(u'%{0}%'.format(keyword)),
+                    Email.subject.like(u'%{0}%'.format(keyword), case_sensitive = False),
                 )).order_by(Desc(Email.date))
         return emails
 
@@ -328,6 +328,7 @@ class StormStore(object):
                     Email.message_id == unicode(message_id)
                 )).count()
 
+
     def get_list_names(self):
         """Return the names of the archived lists.
 
@@ -409,8 +410,7 @@ class StormStore(object):
 
     def get_thread_neighbors(self, list_name, thread_id):
         """ Return the previous and the next threads of the specified thread,
-        in date order. The returned objects are the emails starting the
-        threads.
+        in date order.
 
         :param list_name: The name of the mailing list to query.
         :param thread_id: The unique identifier of the thread as specified in
@@ -419,26 +419,24 @@ class StormStore(object):
             this order.
         :rtype: tuple
         """
-        current_email = self.get_message_by_hash_from_list(list_name, thread_id)
-        next_email = self.db.find(Email, And(
-                    Email.list_name == unicode(list_name),
-                    Email.in_reply_to == None,
-                    Email.date > current_email.date,
-                )).order_by(Email.date)
+        thread = self.get_thread(list_name, thread_id)
+        next_thread = self.db.find(Thread, And(
+                    Thread.list_name == unicode(list_name),
+                    Thread.date_active > thread.date_active,
+                )).order_by(Thread.date_active)
         try:
-            next_email = next_email[0]
+            next_thread = next_thread[0]
         except IndexError:
-            next_email = None
-        prev_email = self.db.find(Email, And(
-                    Email.list_name == unicode(list_name),
-                    Email.in_reply_to == None,
-                    Email.date < current_email.date,
-                )).order_by(Desc(Email.date))
+            next_thread = None
+        prev_thread = self.db.find(Thread, And(
+                    Thread.list_name == unicode(list_name),
+                    Thread.date_active < thread.date_active,
+                )).order_by(Desc(Thread.date_active))
         try:
-            prev_email = prev_email[0]
+            prev_thread = prev_thread[0]
         except IndexError:
-            prev_email = None
-        return (prev_email, next_email)
+            prev_thread = None
+        return (prev_thread, next_thread)
 
     def get_list(self, list_name):
         """ Return the list object for a mailing list name.
